#
# spec file for package ignition-dracut
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ignition-dracut
Version:        0.0+git20200504.7ff38d9
Release:        bp153.1.15
Summary:        Dracut scripts for ignition
License:        BSD-2-Clause
Group:          System/Management
URL:            https://github.com/dustymabe/ignition-dracut
Source:         %{name}-%{version}.tar.xz
Source1:        ignition-mount-initrd-fstab.service
Source3:        ignition-suse-generator
Source4:        module-setup.sh
Source5:        02_ignition_firstboot
Source6:        change-ignition-firstboot-path.conf
Source7:        README.SUSE
Source8:        ignition-setup-user-suse.sh
Source9:        prevent-boot-cycle.conf
Source20:       ignition-userconfig-timeout.conf
Source21:       ignition-userconfig-timeout-arm.conf
Patch3:         0003-Disable-resetting-UUID.patch
BuildRequires:  suse-module-tools
BuildRequires:  update-bootloader-rpm-macros
PreReq:         sed
PreReq:         grub2
PreReq:         virt-what
Requires:       gptfdisk
Requires:       ignition
%{update_bootloader_requires}

%description
Ignition is an utility to manipulate disks and configuration files during
the initramfs. This includes partitioning disks, formatting partitions,
writing files (regular files, systemd units, etc.), and creating users.
On first boot, Ignition reads its configuration from a source of truth
(remote URL, network metadata service, hypervisor bridge, etc.) and applies
the configuration.
This package contains the dracut scripts for this.

%prep
%setup -q
%patch3 -p1
mkdir dracut/30ignition-microos grub
chmod +x %{SOURCE3} %{SOURCE4} %{SOURCE8}
cp %{SOURCE1} %{SOURCE3} %{SOURCE4} %{SOURCE8} %{SOURCE9} dracut/30ignition-microos/
%ifarch aarch64 %{arm}
cp %{SOURCE21} dracut/30ignition-microos/ignition-userconfig-timeout.conf
%else
cp %{SOURCE20} dracut/30ignition-microos/ignition-userconfig-timeout.conf
%endif
cp %{SOURCE5} grub/
cp %{SOURCE6} systemd/
cp %{SOURCE7} .

%build

%install
install -d %{buildroot}%{_sysconfdir}/grub.d
install -d %{buildroot}%{_prefix}/lib/dracut/modules.d
install -d %{buildroot}%{_prefix}/lib/systemd/system
install -d %{buildroot}%{_prefix}/lib/systemd/system/ignition-firstboot-complete.service.d
install -p -m 0755 grub/* %{buildroot}%{_sysconfdir}/grub.d/
cp -av dracut/[0-9]* %{buildroot}%{_prefix}/lib/dracut/modules.d/
install -p -m 0644 systemd/*.service %{buildroot}%{_prefix}/lib/systemd/system/
install -p -m 0644 systemd/*.conf %{buildroot}%{_prefix}/lib/systemd/system/ignition-firstboot-complete.service.d/

%files
%license LICENSE
%doc README.SUSE
%{_sysconfdir}/grub.d
%{_prefix}/lib/dracut
%{_prefix}/lib/systemd/system/*
%config %{_sysconfdir}/grub.d/02_ignition_firstboot

%pre
%service_add_pre ignition-firstboot-complete.service

%post
%{?regenerate_initrd_post}
if [ "$1" = 1 ] ; then
    platform="$(virt-what)"
    case "${platform}" in
        *vmware*)     platform="vmware" ;;
        *virtualbox*) platform="virtualbox" ;;
        *kvm*|*qemu*) platform="qemu" ;;
        *)            platform="metal" ;;
    esac
    sed -i 's/^\(GRUB_CMDLINE_LINUX_DEFAULT="\)\(.*\)/\1ignition.platform.id='${platform}' \\$ignition_firstboot \2/' %{_sysconfdir}/default/grub
    %{?update_bootloader_refresh_post}
    # Trigger setting firstboot flag (in posttrans) only on new installations
    mkdir -p %{_rundir}/ignition-dracut/
    touch %{_rundir}/ignition-dracut/newinstall
fi
%service_add_post ignition-firstboot-complete.service

%preun
%service_del_preun ignition-firstboot-complete.service

%postun
if [ "$1" = 0 ] ; then
    sed -i -E '/^GRUB_CMDLINE_LINUX_DEFAULT="/s/(\\\$)?ignition[._][^[:space:]"]+ ?//g' %{_sysconfdir}/default/grub
    rm -f /boot/writable/ignition.firstboot
fi
%service_del_postun -n ignition-firstboot-complete.service

%posttrans
%{?regenerate_initrd_posttrans}
if test -f %{_rundir}/ignition-dracut/newinstall; then
    %{?update_bootloader_posttrans}
    mkdir -p /boot/writable
    touch /boot/writable/ignition.firstboot
fi

%changelog
* Mon May 11 2020 iforster@suse.com
- Update to version 0.0+git20200504.7ff38d9:
  * 30ignition: drop hard requirement on qemu_fw_cfg [boo#1167289]
  * 99emergency-timeout: improve readability of Ignition failure message
  * 99emergency-timeout: also check ignition-fetch.service for failure
  * coreos-teardown-initramfs-network: don't run when emergency.target
  * dracut: add logging to systemd generator
  * coreos-teardown-initramfs-network: also propagate hostname
  * coreos-teardown-initramfs-network: support coreos.no_persist_ip karg
  * coreos-teardown-initramfs-network: consider ifcfg files in real root for RHCOS
  * coreos-teardown-initramfs-network: also skip local loopback interface
  * coreos-teardown-initramfs-network: do SELinux relabel on copied files
  * coreos-teardown-initramfs-network: order ExecStop after other ignition units
  * coreos-teardown-initramfs-network: remove After=ignition-files.service
  * Add ignition-virtio-dump-journal.service
* Fri Mar 27 2020 iforster@suse.com
- Update to version 0.0+git20200325.ea3bdc9:
  * Add `basename` dependency to dracut module [boo#1167289]
  * coreos-teardown-initramfs-network: enable the service statically
  * coreos-teardown-initramfs-network: simplify networking takedown
  * coreos-teardown-initramfs-network: take down routes too
  * coreos-teardown-initramfs-network: take down teams as well
  * coreos-teardown-initramfs-network: remove state files on switch
  * coreos-teardown-initramfs-network: also propagate initramfs networking if desired
  * coreos-teardown-initramfs-network: refactor into more functions
  * add coreos-teardown-initramfs-network.service
  * Declare external applications as optional [boo#1167289]
  * Remove obsolete dependencies [boo#1167289]
  * Hook up to CoreOS CI
  * Add ignition-diskful-subsequent.target
  * Makefile: Remove grub/ install bits
  * grub: drop 02_ignition_firstboot
- As the GRUB module was dropped upstream and is now generated as part of a
  CoreOS specific module, we will do the same:
  * Move previous 02_ignition_firstboot to MicroOS dracut module
  * Merge 0002-Support-different-flagfile-location.patch and
    01_suse_set_ignition into custom 02_ignition_firstboot
- Updated README.SUSE to describe all current SUSE modifications
* Wed Mar  4 2020 Ignaz Forster <iforster@suse.com>
- Don't use new systemd RPM macros for compatibility with older
  releases.
* Thu Jan  9 2020 Ignaz Forster <iforster@suse.com>
- Add prevent-boot-cycle.conf to prevent a systemd reboot cycle if
  the files stage should be failing; this is a temporary workaround
  until [gh#coreos/ignition-dracut#115] is fixed.
* Wed Jan  8 2020 iforster@suse.com
- Update to version 0.0+git20200107.e490517:
  * Make setfiles optional
* Sun Jan  5 2020 Thorsten Kukuk <kukuk@suse.com>
- Really increase timeout for 'ignition' device on ARM
* Mon Dec 23 2019 Ignaz Forster <iforster@suse.com>
- Update to version 0.0+git20191211.c4790bc:
  * dracut: add some bins for s390x zVM instalation
  * README.md: add details about the branches here
  * units: add ConditionPathExists=/etc/initrd-release everywhere
  * Add ConditionPathExists=/etc/initrd-release to targets
  * 30ignition: add setfiles
- Make package arch dependent to make the ARM fix actually apply
* Mon Nov 11 2019 kukuk@suse.de
- Update to version 0.0+git20191107.d9e8a63:
  * 30ignition/ignition-setup-user: mount /boot partition ro
  * firstboot-complete: tell zipl to run
  * coreos-gpt-setup: workaround old lsblk not having PTUUID
  * Add `ignition-subsequent.target` for non-Ignition boots
  * ignition-firstboot-complete.service: Run as part of basic.target
- Increase timeout for 'ignition' device on ARM
- Prefer Ignition configuration if a mount point is both configured
  in Ignition and fstab (x-initrd.mount flag)
- Explicitly add awk as initrd dependency
* Fri Oct  4 2019 Ignaz Forster <iforster@suse.com>
- Fix missing executable permission for ignition-setup-user-suse.sh
* Wed Oct  2 2019 kukuk@suse.de
- Update to version 0.0+git20191001.cefb71c:
  * Run ignition-disks earlier to avoid race condition
  * 30ignition: update ignition-complete.target OnFailure comment
  * 30ignition: drop OnFailure handler from ignition-diskful.target
  * 30ignition: fix sequencing of target dependencies
- Don't error out in ignition-setup-user-suse.sh if Ignition device
  is not present
* Fri Sep 27 2019 kukuk@suse.de
- Update to version 0.0+git20190924.aada644:
  * dracut: Add an ignition-fetch.service
  * Add RemainAfterExit=yes to systemd units of Type=oneshot
  * Makefile: New file implementing `make install`
  * 30ignition: move coreos-gpt-setup RemainAfterExit to correct section
  * 30ignition: on live images, read config.ign from custom initrd
  * 30ignition: make ignition-diskful a dependency of ignition-complete
  * 30ignition: fix double slash in ignition-setup-* dest paths
- Drop 0001-Read-user-config.patch: Migrated to systemd drop-in files now that
  ignition-diskful is a separate target
* Tue Sep 17 2019 kukuk@suse.de
- Update to version 0.0+git20190916.cbac371:
  * systemd: don't try to mark live boots complete
  * 30ignition: conditionally enable units requiring a boot disk
  * README.md: fix download link
  * update-bootengine: drop file
  * dracut/30ignition: localize some variables
  * ignition: fix correct device path when randomizing UUID
- Fix path to rm binary in firstboot flag cleanup
- Reorder $ignition_firstboot and ignition.platform.id in GRUB's
  kernel parameter line to be able to overwrite the later with
  values read from the flag file
- Significantly decrease timeout for waiting for a device with
  the 'ignition' UUID (storing an eventual user config)
  [boo#1151083]
- Merge ignition-umount-initrd-fstab.service with
  ignition-mount-initrd-fstab.service, using the same stop
  mechanism as ignition-mount.service
* Wed Aug 14 2019 kukuk@suse.de
- Update to version 0.0+git20190806.343b886:
  * dracut/30ignition: fix typo in module_setup
  * ignition: split ignition-setup into base and user
  * dracut/30ignition: scramble disk uuid on 1st boot
* Thu Aug  1 2019 kukuk@suse.de
- Update to version 0.0+git20190625.8551bc7:
  * dracut: add 99emergency-timeout
  * 30ignition: drop CoreOS specific bits
* Mon Apr 15 2019 kukuk@suse.de
- Update to version 0.0+git20190405.85f2e65:
  * dracut/30ignition: link to RHBZ in ignition-complete
  * dracut/30ignition: add OnFailure= for ExecStop= services
  * dracut/30ignition: order ExecStop= units before initrd-switch-root.target
  * dracut/30ignition: re-order directives in remount-sysroot
  * dracut/30ignition: add missing Before= for mount unit
  * dracut/30ignition: order ignition-complete.target before initrd.target
  * module_setup: include cdrom rules for openstack
  * dracut: add CoreOS integration services
  * dracut/30ignition: Add mount stage and drop OSTree-specific bits
  * dracut/30ignition: Explicitly add OnFailure=emergency.target
  * 30ignition: ignore coreos.randomize_disk_guid
  * 30ignition: drop check for coreos.oem.id
  * grub: support overriding network kcmdline args
  * README.md: update documentation
  * 02_ignition_firstboot: Enable networking if Ignition will run
  * dracut/30ignition: expect ignition binary in module directory
* Mon Mar 18 2019 kukuk@suse.de
- Update to version 0.0+git20190314.f6eb01f:
  * dracut/30ignition: add ignition-complete.target
  * dracut/30ignition: split out ignition-setup.service
* Tue Mar 12 2019 Ignaz Forster <iforster@suse.com>
- Add GRUB firstboot variable support
- Weaken hard dependencies to boot partition
- Mount volumes flagged with "x-initrd.mount" before applying
  Ignition configuration; umount afterwards
* Sat Mar  9 2019 kukuk@suse.de
- Update to version 0.0+git20190306.d4e8899:
  * dracut/30ignition: Only write ignition-setup.service on first boot
  * grub: find boot partition and use it directly
  * module-setup.sh: Check for module qemu_fw_cfg not build-in, so it works out of box on all arches
* Mon Mar  4 2019 kukuk@suse.de
- Update to version 0.0+git20190301.ca593a1:
  * dracut/30ignition: general hack cleanups
  * dracut: adapt for s/oem/platform in Ignition
* Tue Feb 19 2019 kukuk@suse.de
- Update to version 0.0+git20190215.2c69925:
  * ignition-setup: don't perform umount, rely on systemd
  * ignition-setup: rename copy function
  * services: fixup unit deps to more match CL
  * ignition-setup: use MountFlags=slave for systemd unit
  * ignition-setup: changes from code review
  * ignition-setup: mount/unmount boot to grab user.ign
  * dracut: add /usr/sbin/ignition-setup to initramfs
  * generator: try to get ignition-setup to run on boot
  * generator: RemainAfterExit=yes for ignition-setup
  * ignition-setup: support boot or platform base/user configs
  * ignition-setup: remove support for default configs
* Fri Feb 15 2019 kukuk@suse.de
- Update to version 0.0+git20190207.9e18211:
  * Remove the check for OEM partition, not used
  * Always check for boot, needs to exist
  * Replace OEM with boot
  * Add ability to parse config.ign file on boot
* Wed Jan 30 2019 kukuk@suse.de
- Update to version 0.0+git20190125.fa7131b:
  * journal: add clarifying comment for context
* Wed Jan  9 2019 kukuk@suse.de
- Update to version 0.0+git20190109.a6551f1:
  * Remount /sysroot rw (#38)
* Wed Jan  9 2019 kukuk@suse.de
- Update to version 0.0+git20190103.996d527:
  * ignition-firstboot-complete.service: Remount /boot rw
* Sun Dec 23 2018 kukuk@suse.de
- Remout /sysroot read-write for ignition-files.service
* Wed Dec 19 2018 kukuk@suse.de
- Generate initrd after installation/update
* Wed Dec 12 2018 kukuk@suse.de
- Update to version 0.0+git20181120.7b83454:
  * Rename `coreos.firstboot` kernel cmdline arg to `ignition.firstboot` to make options more distribution neutral. Update dracut/README.txt to take into account recent changes.
  * 30ignition: only instmods if module available
  * remove ignition-remount-sysroot.service files
  * ignition: run files stage at original CL ordering
  * ignition-disks.service: drop Requires=network.target
  * ignition-ask-var-mount.service: use RemainAfterExit=yes
* Wed Oct 17 2018 kukuk@suse.de
- Update to version 0.0+git20181016.b7d4424:
  * module-setup.sh: explicitly install qemu_fw_cfg
* Tue Oct 16 2018 kukuk@suse.de
- Add requires for ignition and gptfdisk
* Tue Oct 16 2018 kukuk@suse.de
- Initial version
